@@ -114,10 +114,11 @@ class CompileSectionGenerator(SectionGenerator):
 
 
 class CompileScriptsSectionGenerator(SectionGenerator):
-	def __init__(self, dependency_files, repo_root):
+	def __init__(self, dependency_files, repo_root, options):
 		super(CompileScriptsSectionGenerator, self).__init__()
 		self.dependency_files = dependency_files
 		self.repo_root = repo_root
+		self.options = options
 
 	def _get_compile_section(self, name, directory, install_script):
 		inner = {'script': install_script}
@@ -144,10 +145,11 @@ class TestSectionGenerator(SectionGenerator):
 
 
 class TestFactorySectionGenerator(SectionGenerator):
-	def __init__(self, dependency_files, repo_root):
+	def __init__(self, dependency_files, repo_root, options):
 		super(TestFactorySectionGenerator, self).__init__()
 		self.dependency_files = dependency_files
 		self.repo_root = repo_root
+		self.options = options
 
 	def _get_factory_section(self, test_dir, directory, test_factory_script):
 		assert isinstance(test_factory_script, str)
