@@ -38,6 +38,8 @@ class DependencyReflector(Reflector):
 			return 'ruby'
 		elif name == 'pom.xml':
 			return 'java'
+		elif 'Gruntfile' in name:
+			return 'javascript'
 
 	def _is_package_manager_file(self, name):
-		return name in ['package.json', 'Gemfile', 'Rakefile', 'pom.xml'] or name.endswith('requirements.txt')
+		return name in ['package.json', 'Gemfile', 'Rakefile', 'pom.xml'] or name.endswith('requirements.txt') or 'Gruntfile' in name
